@@ -1,9 +1,9 @@
-#' Districts of Prague and other major cities
+#' City Parts
+#'
+#' Function taking no parameters and returning data frame of districts of Prague and other major cities as sf polygons.
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 593.6 KB.
 #'
-#' casti() is a function taking no parameters and returning a data frame; remember to use (empty) brackets in your call.
-#'
 #' @format sf data frame with 142 rows of 4 variables + geometry
 #'
 #' \describe{
@@ -17,13 +17,11 @@
 #'
 #'
 #' @export
-#' @importFrom httr http_error
 
 casti <- function() {
   remote_df <- 'http://rczechia.jla-data.net/casti.rds'
   if (http_error(remote_df)) {
-    warning('No internet connection or data source broken.')
-    return(NA)
+    stop('No internet connection or data source broken.')
   } else {
     local_df <- readRDS(url(remote_df))
   }
