@@ -1,11 +1,9 @@
 #' Municipalities / communes (obce) as polygons
 #'
-#' LAU2 administrative unit for the Czech Republic.
+#' Function returning data frame of LAU2 administrative units for the Czech Republic as sf polygons. It takes no parameters.
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 36.3 MB (so use with caution, and patience).
 #'
-#'  obce_polygony() is a function taking no parameters and returning a data frame; remember to use (empty) brackets in your call.
-#'
 #' @format sf data frame with 6.258 rows of 14 variables + geometry
 #'
 #' \describe{
@@ -38,13 +36,11 @@
 #'
 #'
 #' @export
-#' @importFrom httr http_error
 
 obce_polygony <- function() {
   remote_df <- 'http://rczechia.jla-data.net/ObceP.rds'
   if (http_error(remote_df)) {
-    warning('No internet connection or data source broken.')
-    return(NA)
+    stop('No internet connection or data source broken.')
   } else {
     local_df <- readRDS(url(remote_df))
   }
