@@ -1,9 +1,9 @@
-#' Water bodies of the Czech Republic
+#' Water Bodies
+#'
+#' Function returning data frame of water bodies of the Czech Republic as sf polygons. It takes no parameters.
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 118.6 KB.
 #'
-#'  plochy() is a function taking no parameters and returning a data frame; remember to use (empty) brackets in your call.
-#'
 #' @format sf data frame with 480 rows of 5 variables + geometry
 #'
 #' \describe{
@@ -18,13 +18,11 @@
 #'
 #'
 #' @export
-#' @importFrom httr http_error
 
 plochy <- function() {
   remote_df <- 'http://rczechia.jla-data.net/Plochy.rds'
   if (http_error(remote_df)) {
-    warning('No internet connection or data source broken.')
-    return(NA)
+    stop('No internet connection or data source broken.')
   } else {
     local_df <- readRDS(url(remote_df))
   }
